@@ -36,9 +36,8 @@ public:
      * @param value is the initial service to select (not implemented currently)
      * @param parent parent widget
      */
-    explicit KServiceSelectDlg( const QString& serviceType,
-                                const QString& value = QString(),
-                                QWidget *parent = nullptr );
+    explicit KServiceSelectDlg(const QString &serviceType,
+                               const QString &value = QString(), QWidget *parent = nullptr);
 
     ~KServiceSelectDlg() override;
 
@@ -48,8 +47,8 @@ public:
     KService::Ptr service();
 
 private:
-    QListWidget * m_listbox;
-    QDialogButtonBox* m_buttonBox;
+    QListWidget *m_listbox;
+    QDialogButtonBox *m_buttonBox;
 };
 
 #endif
