@@ -22,6 +22,7 @@
 #include <kconfiggroup.h>
 #include <kdesktopfile.h>
 #include <ksycoca.h>
+#include <kcoreaddons_version.h>
 
 // Qt
 #include <QProcess>
@@ -34,6 +35,8 @@
 #include <mimetypedata.h>
 #include <mimetypewriter.h>
 
+// Unfortunately this isn't available in non-developer builds of Qt...
+//extern Q_CORE_EXPORT int qmime_secondsBetweenChecks; // see qmimeprovider.cpp
 
 class FileTypesTest : public QObject
 {
@@ -42,45 +45,45 @@ class FileTypesTest : public QObject
 private Q_SLOTS:
     void initTestCase()
     {
-        extern KSERVICE_EXPORT bool kservice_require_kded;
-        kservice_require_kded = false;
-
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 73, 0)
+        QLoggingCategory::setFilterRules(QStringLiteral("kf.coreaddons.kdirwatch.debug=true"));
+#else
         QLoggingCategory::setFilterRules(QStringLiteral("kf5.kcoreaddons.kdirwatch.debug=true"));
+#endif
 
         QStandardPaths::setTestModeEnabled(true);
 
+        // update-mime-database needs to know about that test directory for the mimetype pattern change in testMimeTypePatterns to have an effect
+        qputenv("XDG_DATA_HOME", QFile::encodeName(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)));
+
         m_mimeTypeCreatedSuccessfully = false;
-        QStringList appsDirs = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+        QStringList appsDirs = QStandardPaths::standardLocations(
+            QStandardPaths::ApplicationsLocation);
         //qDebug() << appsDirs;
         m_localApps = appsDirs.first() + QLatin1Char('/');
-        m_localConfig = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
-        QVERIFY(QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/mime/packages")));
+        m_localConfig
+            = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
+        QVERIFY(QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
+                              + QStringLiteral("/mime/packages")));
 
         QFile::remove(m_localConfig.filePath(QStringLiteral("mimeapps.list")));
+        QFile::remove(m_localConfig.filePath(QStringLiteral("filetypesrc")));
 
         // Create fake applications for some tests below.
-        bool mustUpdateKSycoca = false;
         fakeApplication = QStringLiteral("fakeapplication.desktop");
-        if (createDesktopFile(m_localApps + fakeApplication))
-            mustUpdateKSycoca = true;
+        createDesktopFile(m_localApps + fakeApplication, {QStringLiteral("image/png")});
         fakeApplication2 = QStringLiteral("fakeapplication2.desktop");
-        if (createDesktopFile(m_localApps + fakeApplication2))
-            mustUpdateKSycoca = true;
+        createDesktopFile(m_localApps + fakeApplication2, {QStringLiteral("image/png"), QStringLiteral("text/plain")});
 
         // Cleanup after testMimeTypePatterns if it failed mid-way
-        const QString packageFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + QStringLiteral("packages/text-plain.xml") ;
+        const QString packageFileName = QStandardPaths::writableLocation(
+            QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + QStringLiteral(
+            "packages/text-plain.xml");
         if (!packageFileName.isEmpty()) {
             QFile::remove(packageFileName);
             MimeTypeWriter::runUpdateMimeDatabase();
-            mustUpdateKSycoca = true;
         }
 
-        QFile::remove(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + QStringLiteral("filetypesrc"));
-
-        if ( mustUpdateKSycoca ) {
-            // Update ksycoca in ~/.kde-unit-test after creating the above
-            runKBuildSycoca();
-        }
         KService::Ptr fakeApplicationService = KService::serviceByStorageId(fakeApplication);
         QVERIFY(fakeApplicationService);
     }
@@ -156,7 +159,7 @@ private Q_SLOTS:
         QVERIFY(!data.isDirty());
         data.setPatterns(patterns);
         QVERIFY(data.isDirty());
-        bool needUpdateMimeDb = data.sync();
+        const bool needUpdateMimeDb = data.sync();
         QVERIFY(needUpdateMimeDb);
         MimeTypeWriter::runUpdateMimeDatabase();
 
@@ -167,11 +170,18 @@ private Q_SLOTS:
         // Check what's in QMimeDatabase
         QStringList newPatterns = db.mimeTypeForName(QStringLiteral("text/plain")).globPatterns();
         newPatterns.sort();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) // adjust to 5.15 if the fix gets backported
+        QEXPECT_FAIL("", "QTBUG-85436 is only fixed in Qt 6.0", Continue);
+#endif
         QCOMPARE(newPatterns, patterns);
-        QVERIFY(!data.isDirty());
+        if (newPatterns == patterns) { // TODO Qt6: remove the if (keep the QVERIFY!)
+            QVERIFY(!data.isDirty());
+        }
 
         // And then removing the custom file by hand should revert to the initial state
-        const QString packageFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + QStringLiteral("packages/text-plain.xml") ;
+        const QString packageFileName = QStandardPaths::writableLocation(
+            QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + QStringLiteral(
+            "packages/text-plain.xml");
         QVERIFY(!packageFileName.isEmpty());
         QFile::remove(packageFileName);
         MimeTypeWriter::runUpdateMimeDatabase();
@@ -188,8 +198,7 @@ private Q_SLOTS:
         MimeTypeData data(db.mimeTypeForName(mimeTypeName));
         QStringList appServices = data.appServices();
         //qDebug() << appServices;
-        QVERIFY(!appServices.isEmpty());
-        const QString oldPreferredApp = appServices.first();
+        QVERIFY(appServices.contains(fakeApplication2));
         QVERIFY(!appServices.contains(fakeApplication)); // already there? hmm can't really test then
         QVERIFY(!data.isDirty());
         appServices.prepend(fakeApplication);
@@ -215,6 +224,9 @@ private Q_SLOTS:
         // Check what's in mimeapps.list
         checkAddedAssociationsContains(mimeTypeName, fakeApplication);
 
+        // Then we get the signal that kbuildsycoca changed
+        data.refresh();
+
         // Now test removing (in the same test, since it's inter-dependent)
         QVERIFY(appServices.removeAll(fakeApplication) > 0);
         data.setAppServices(appServices);
@@ -275,8 +287,9 @@ private Q_SLOTS:
         QMimeDatabase db;
         const QString mimeTypeName = QStringLiteral("fake/unit-test-fake-mimetype");
         // Clean up after previous runs if necessary
-        if (MimeTypeWriter::hasDefinitionFile(mimeTypeName))
+        if (MimeTypeWriter::hasDefinitionFile(mimeTypeName)) {
             MimeTypeWriter::removeOwnMimeType(mimeTypeName);
+        }
 
         MimeTypeData data(mimeTypeName, true);
         data.setComment(QStringLiteral("Fake MimeType"));
@@ -285,9 +298,8 @@ private Q_SLOTS:
         QVERIFY(data.isDirty());
         QVERIFY(data.sync());
         MimeTypeWriter::runUpdateMimeDatabase();
-        //runKBuildSycoca();
         // QMimeDatabase doesn't even try to update the cache if less than
-        // 5000 ms have passed
+        // 5000 ms have passed (can't use qmime_secondsBetweenChecks)
         QTest::qSleep(5000);
         QMimeType mime = db.mimeTypeForName(mimeTypeName);
         QVERIFY(mime.isValid());
@@ -295,7 +307,9 @@ private Q_SLOTS:
         QCOMPARE(mime.globPatterns(), patterns); // must sort them if more than one
 
         // Testcase for the shaman.xml bug
-        QCOMPARE(db.mimeTypeForFile(QStringLiteral("/whatever/foo.pkg.tar.gz")).name(), QStringLiteral("fake/unit-test-fake-mimetype"));
+        QCOMPARE(db.mimeTypeForFile(QStringLiteral(
+                                        "/whatever/foo.pkg.tar.gz")).name(),
+                 QStringLiteral("fake/unit-test-fake-mimetype"));
 
         m_mimeTypeCreatedSuccessfully = true;
     }
@@ -303,15 +317,18 @@ private Q_SLOTS:
     void testDeleteMimeType()
     {
         QMimeDatabase db;
-        if (!m_mimeTypeCreatedSuccessfully)
+        if (!m_mimeTypeCreatedSuccessfully) {
             QSKIP("This test relies on testCreateMimeType");
+        }
         const QString mimeTypeName = QStringLiteral("fake/unit-test-fake-mimetype");
         QVERIFY(MimeTypeWriter::hasDefinitionFile(mimeTypeName));
         MimeTypeWriter::removeOwnMimeType(mimeTypeName);
         MimeTypeWriter::runUpdateMimeDatabase();
-        //runKBuildSycoca();
-        QMimeType mime = db.mimeTypeForName(mimeTypeName);
-        QVERIFY(mime.isValid());
+        // QMimeDatabase doesn't even try to update the cache if less than
+        // 5000 ms have passed (can't use qmime_secondsBetweenChecks)
+        QTest::qSleep(5000);
+        const QMimeType mime = db.mimeTypeForName(mimeTypeName);
+        QVERIFY2(!mime.isValid(), qPrintable(mimeTypeName));
     }
 
     void testModifyMimeTypeComment() // of a system mimetype. And check that it's re-read correctly.
@@ -325,7 +342,6 @@ private Q_SLOTS:
         QVERIFY(data.isDirty());
         QVERIFY(data.sync());
         MimeTypeWriter::runUpdateMimeDatabase();
-        //runKBuildSycoca();
         QMimeType mime = db.mimeTypeForName(mimeTypeName);
         QVERIFY(mime.isValid());
         QCOMPARE(mime.comment(), fakeComment);
@@ -337,15 +353,17 @@ private Q_SLOTS:
 
     void cleanupTestCase()
     {
-        // If we remove it, then every run of the unit test has to run kbuildsycoca... slow.
-        //QFile::remove(QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation) + QLatin1Char('/') + "fakeapplication.desktop");
+        const QString localAppsDir = QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation);
+        QFile::remove(localAppsDir + QLatin1String("/fakeapplication.desktop"));
+        QFile::remove(localAppsDir + QLatin1String("/fakeapplication2.desktop"));
     }
 
 private: // helper methods
 
-    void checkAddedAssociationsContains(const QString& mimeTypeName, const QString& application)
+    void checkAddedAssociationsContains(const QString &mimeTypeName, const QString &application)
     {
-        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")), KConfig::NoGlobals);
+        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")),
+                             KConfig::NoGlobals);
         const KConfigGroup group(&config, "Added Associations");
         const QStringList addedEntries = group.readXdgListEntry(mimeTypeName);
         if (!addedEntries.contains(application)) {
@@ -354,9 +372,10 @@ private: // helper methods
         }
     }
 
-    void checkRemovedAssociationsContains(const QString& mimeTypeName, const QString& application)
+    void checkRemovedAssociationsContains(const QString &mimeTypeName, const QString &application)
     {
-        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")), KConfig::NoGlobals);
+        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")),
+                             KConfig::NoGlobals);
         const KConfigGroup group(&config, "Removed Associations");
         const QStringList removedEntries = group.readXdgListEntry(mimeTypeName);
         if (!removedEntries.contains(application)) {
@@ -365,9 +384,11 @@ private: // helper methods
         }
     }
 
-    void checkRemovedAssociationsDoesNotContain(const QString& mimeTypeName, const QString& application)
+    void checkRemovedAssociationsDoesNotContain(const QString &mimeTypeName,
+                                                const QString &application)
     {
-        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")), KConfig::NoGlobals);
+        const KConfig config(m_localConfig.filePath(QStringLiteral("mimeapps.list")),
+                             KConfig::NoGlobals);
         const KConfigGroup group(&config, "Removed Associations");
         const QStringList removedEntries = group.readXdgListEntry(mimeTypeName);
         if (removedEntries.contains(application)) {
@@ -383,7 +404,8 @@ private: // helper methods
 
         QProcess proc;
         //proc.setProcessChannelMode(QProcess::ForwardedChannels);
-        const QString kbuildsycoca = QStandardPaths::findExecutable(QLatin1String(KBUILDSYCOCA_EXENAME));
+        const QString kbuildsycoca
+            = QStandardPaths::findExecutable(QLatin1String(KBUILDSYCOCA_EXENAME));
         QVERIFY(!kbuildsycoca.isEmpty());
         QStringList args;
         args << QStringLiteral("--testmode");
@@ -395,26 +417,23 @@ private: // helper methods
         qDebug() << "got signal";
     }
 
-    bool createDesktopFile(const QString& path)
+    void createDesktopFile(const QString& path, const QStringList &mimeTypes)
     {
-        if (!QFile::exists(path)) {
-            KDesktopFile file(path);
-            KConfigGroup group = file.desktopGroup();
-            group.writeEntry("Name", "FakeApplication");
-            group.writeEntry("Type", "Application");
-            group.writeEntry("Exec", "ls");
-            group.writeEntry("MimeType", "image/png");
-            return true;
-        }
-        return false;
+        KDesktopFile file(path);
+        KConfigGroup group = file.desktopGroup();
+        group.writeEntry("Name", "FakeApplication");
+        group.writeEntry("Type", "Application");
+        group.writeEntry("Exec", "ls");
+        group.writeXdgListEntry("MimeType", mimeTypes);
     }
 
-    void checkMimeTypeServices(const QString& mimeTypeName, const QStringList& expectedServices)
+    void checkMimeTypeServices(const QString &mimeTypeName, const QStringList &expectedServices)
     {
         QMimeDatabase db;
         MimeTypeData data2(db.mimeTypeForName(mimeTypeName));
-        if (data2.appServices() != expectedServices)
+        if (data2.appServices() != expectedServices) {
             qDebug() << "got" << data2.appServices() << "expected" << expectedServices;
+        }
         QCOMPARE(data2.appServices(), expectedServices);
     }
 
