@@ -55,9 +55,11 @@ public:
          * if the path starts with http:// or any other scheme, except file://
          * we also don't want to do anything with URL
          */
-        if (!QUrl(pathOrUrl).isLocalFile()) {
+        if (!QUrl::fromUserInput(pathOrUrl).isLocalFile()) {
             url = QUrl::fromUserInput(pathOrUrl, QDir::currentPath(), QUrl::DefaultResolution);
-            return;
+            // relative paths are not isLocalFile(), but not valid too, so we don't want them
+            if(url.isValid())
+                return;
         }
 
         /**
